@@ -270,11 +270,11 @@ class PlaylistsPanel(object):
                 "paths.id=tracks.path ORDER " \
                 "BY plays ASC LIMIT 100"),
 
-            (_('Rating > 5'), "SELECT paths.name FROM paths, tracks, artists, " \
+            (_('Rating > 4'), "SELECT paths.name FROM paths, tracks, artists, " \
                 "albums " \
                 "WHERE tracks.path=paths.id AND albums.id=tracks.album AND " \
                 "artists.id=tracks.artist " \
-                "AND user_rating > 5 " \
+                "AND user_rating > 4 " \
                 "ORDER BY LOWER(artists.name), THE_CUTTER(albums.name), track"),
             
             (_('Rating > 3'), "SELECT paths.name FROM paths,tracks,artists,albums WHERE " \
@@ -504,7 +504,7 @@ class PlaylistsPanel(object):
             playlist_id = library.get_column_id(self.db, 'playlists', 'name', playlist)
 
             rows = self.db.select('SELECT paths.name FROM playlist_items,paths '
-                'WHERE playlist_items.path=paths.id AND playlist=?',
+                'WHERE playlist_items.path=paths.id AND playlist=? ORDER BY playlist_items.sort_index',
                 (playlist_id,))
 
             songs = library.TrackData()
@@ -668,7 +668,7 @@ class PlaylistsPanel(object):
 
     def add_items_to_playlist(self, playlist, songs=None):
         """
-            Adds the selected tracks tot he playlist
+            Adds the selected tracks to the playlist
         """
         if type(playlist) == gtk.MenuItem:
             playlist = playlist.get_child().get_label()
